@@ -74,7 +74,7 @@ sdp_supply <- function (Q, capacity, target, surface_area, max_depth, evap,
     S_states <- seq(from = 0, to = capacity, by = capacity / S_disc)                   
     R_disc_x <- seq(from = 0, to = target, by = target / R_disc)
     Shell.array <- array(0,dim=c(length(S_states),length(R_disc_x),length(Q.probs)))
-    R.star <- aperm(apply(Shell.array, c(1, 3), "+", R_disc_x), c(2, 1, 3))             
+    #R.star <- aperm(apply(Shell.array, c(1, 3), "+", R_disc_x), c(2, 1, 3))             
     Cost_to_go <- vector("numeric",length=length(S_states))
     Results_mat <- matrix(0,nrow=length(S_states),ncol=frq)
     R_policy <- matrix(0,nrow=length(S_states),ncol=frq)
@@ -94,7 +94,7 @@ sdp_supply <- function (Q, capacity, target, surface_area, max_depth, evap,
     R_disc_x <- seq(from = 0, to = target, by = target / R_disc)
     Shell.array <- array(0, dim = c(length(S_states), length(R_disc_x),
                                     length(Q.probs)))
-    R.star <- aperm(apply(Shell.array, c(1, 3), "+", R_disc_x), c(2, 1, 3))             
+    #R.star <- aperm(apply(Shell.array, c(1, 3), "+", R_disc_x), c(2, 1, 3))             
     Q_class.mat <- matrix(nrow=length(Q_month_mat[,1]),ncol=frq)
     for (m in 1:frq){
       Q_disc_x <- gtools::quantcut(Q_month_mat[,m], Q_disc)
@@ -174,9 +174,8 @@ sdp_supply <- function (Q, capacity, target, surface_area, max_depth, evap,
         R.cstr <- sweep(Shell.array, 3, Q_class_med[,t], "+") +
           sweep(Shell.array, 1, S_states, "+") - 
           sweep(Shell.array, 1, evap_seas[t] * S_area_rel / 10 ^ 6, "+")
+        R.star <- aperm(apply(Shell.array, c(1, 3), "+", R_disc_x), c(2, 1, 3))             
         R.star[,2:(R_disc + 1),][which(R.star[,2:(R_disc + 1),] > R.cstr[,2 : (R_disc + 1),])] <- NaN
-        #R.star[which(R.star > R.cstr)] <- NaN
-        #R.star[,1,][which(is.nan(R.star[,1,])==TRUE)] <- 0 # Ensure lowest release of zero is always allowed
         Deficit.arr <- (R.star - target) / target                                           
         Cost_arr <- ( (abs(Deficit.arr)) ^ loss_exp)                          
         S.t_plus_1 <- R.cstr - R.star
@@ -209,8 +208,8 @@ sdp_supply <- function (Q, capacity, target, surface_area, max_depth, evap,
         R.cstr <- sweep(Shell.array, 3, Q_class_med[,t], "+") +
           sweep(Shell.array, 1, S_states, "+") -
           sweep(Shell.array, 1, evap_seas[t] * S_area_rel / 10 ^ 6, "+")
+        R.star <- aperm(apply(Shell.array, c(1, 3), "+", R_disc_x), c(2, 1, 3))             
         R.star[,2:(R_disc + 1),][which(R.star[,2:(R_disc + 1),] > R.cstr[,2 : (R_disc + 1),])] <- NaN
-        #R.star[which(R.star > R.cstr)] <- NaN                              
         Deficit.arr <- (R.star - target) / target                                           
         Cost_arr <- ( (abs(Deficit.arr)) ^ loss_exp)                          
         S.t_plus_1 <- R.cstr - R.star
@@ -277,7 +276,7 @@ sdp_supply <- function (Q, capacity, target, surface_area, max_depth, evap,
     }
   }
   R_policy <- (R_policy - 1) / R_disc
-  S <- ts(S[1:length(S) - 1],start = start(Q),frequency = frq)
+  S <- ts(S[1:(length(S) - 1)],start = start(Q),frequency = frq)
   R_rec <- ts(R_rec, start = start(Q), frequency = frq)
   E <- ts(E, start = start(Q), frequency = frequency(Q))
   y <- ts(y, start = start(Q), frequency = frequency(Q))
